@@ -10,16 +10,16 @@
 #ifndef __PACKET_TCP_H__
 #define __PACKET_TCP_H__
 
-#ifdef __cplusplus
-extern "C" {
-#endif /* __cplusplus */
-
 #include "ws_symbol_export.h"
 
 #include <epan/conversation.h>
 #include <epan/wmem/wmem.h>
 #include <epan/wmem/wmem_interval_tree.h>
 
+#ifdef __cplusplus
+extern "C" {
+#endif /* __cplusplus */
+
 /* TCP flags */
 #define TH_FIN  0x0001
 #define TH_SYN  0x0002
@@ -446,6 +446,11 @@ struct tcp_analysis {
 	 */
 	guint16 server_port;
 
+	/* Set when the client sends a SYN with data and the cookie in the Fast Open
+	 * option.
+	 */
+	guint8  tfo_syn_data : 1;
+
 	/* allocated only when mptcp enabled
 	 * several tcp_analysis may refer to the same mptcp_analysis
 	 * can exist without any meta
